# 🛰️ CKAN Pilot

**A CLI tool to manage CKAN projects with ease.**
Manage CKAN **project development, operations and maintenance** with a state-of-the-art command-line interface (**CLI**) and modern toolset.

![CKAN Pilot logotype](https://raw.githubusercontent.com/keitaroinc/ckan-pilot/refs/heads/main/CKAN-Pilot-logo.webp)

---

## 📄 Installation guide

- [Installation](https://github.com/keitaroinc/ckan-pilot/wiki/Installation)


## 🚀 Quickstart

1. **Initialize a new project:**

```bash
ckan-pilot init <project_dir>
```

> Once the project is initialized run all commands from the project directory.

2. **Build a distribution of the project:**

```bash
ckan-pilot dist build
```

3. **Start CKAN stack:**

```bash
ckan-pilot start --dev
```

> Run any command with `--help` to see its options.
> To stop the CKAN instance crtl+c in the terminal where it is running.

## 📚 Documentation

For detailed documentation, visit the [CKAN Pilot Documentation](https://github.com/keitaroinc/ckan-pilot/wiki).

---

## 🙌 Contributing

Pull requests and issues are welcome!  
To contribute:

1. Fork the repo  
2. Create a branch  
3. Commit your changes  
4. Open a pull request
